#include "Python.h"
#include "chalib.h"

#define UNLESS(E) if(!(E))

static PyObject *
chalib_chasen_sparse_tostr(PyObject *modinfo, PyObject *args)
{
    char *input_str, *output_str = NULL, *format_str = NULL;
    PyObject *parsed_str;

    UNLESS(PyArg_ParseTuple(args,"s|s", &input_str, &format_str)) return NULL;

    if(format_str) 
      {
	cha_set_opt_form(format_str);
      }

    output_str = chasen_sparse_tostr(input_str);

    UNLESS(parsed_str = PyString_FromString(output_str)) return NULL;
    return parsed_str;
}

static struct PyMethodDef chalib_module_methods[] = {
    { "sparse_tostr", (PyCFunction)chalib_chasen_sparse_tostr, METH_VARARGS,
      "sparse_tostr(input_str [,format_str]) -- Break the given string into words, with a format determined by the format_str",
    },
    { NULL, NULL }		/* sentinel */
};

static char chalib_module_documentation[] = 
"Use ChaLib library to parse source strings into sequences of words\n"
"\n"
"for use with the Catalog\n"
"\n"
"$Id: chalibmodule.c,v 1.1 2001/08/08 07:12:19 norton Exp $\n"
;


void
initchalib() 
{
  PyObject *m, *d;
  char *rev="$Revision: 1.1 $";
  
  /* Create the module and add the functions */
  m = Py_InitModule4("chalib", chalib_module_methods,
                     chalib_module_documentation,
                     (PyObject*)NULL,PYTHON_API_VERSION);
  
  /* Add some symbolic constants to the module */
  d = PyModule_GetDict(m);
  PyDict_SetItemString(d, "__version__",
		       PyString_FromStringAndSize(rev+11,strlen(rev+11)-2));

  if (PyErr_Occurred()) Py_FatalError("can't initialize module chalib");
}
